==> fillets-ng-data-0.7.1.tar.gz: fillets-ng-data-0.7.1/script/chest/dialogs_it.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("E così l'abbiamo finalmente trovato.")

dialogId("tru-m-co", "font_small", "What?")
dialogStr("Cosa?")

dialogId("tru-v-poklad", "font_big", "Captain Silver`s treasure, of course.")
dialogStr("Il tesoro di Capitan Silver, logico.")

dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("Il Sacro Graal, ovvio.")

dialogId("tru-v-vkupe", "font_big", "It`s neatly in one place: the treasure and the Grail.")
dialogStr("Semplicemente in un unico posto: il tesoro e il Graal.")

dialogId("tru-m-zrada", "font_small", "I think it`s much too easy to be true.")
dialogStr("Mi sembra troppo facile per essere vero.")

dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Penso che se questo fosse stato veramente il nostro obiettivo, il giocatore sarebbe stato avvertito.")

dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("Ma ora gliel'ho detto io. Dovrebbe bastare.")

dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Ma io ho messo in dubbio la cosa. Ciò potrebbe confonderlo.")

dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("E va bene. FORSE questo non è quello che cercavamo.")

dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("Così è meglio. Ci rimane un po' di incertezza.")

dialogId("tru-m-truhla0", "font_small", "Couldn`t we close that chest?")
dialogStr("Non potremmo chiudere quello scrigno?")

dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("E se chiudesismo lo scrigno?")

dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Sarebbe molto più facile con lo scrigno chiuso.")

dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Prova a spingere il coperchio.")

dialogId("tru-m-vzit0", "font_small", "Won`t we take something with us?")
dialogStr("Non prendiamo niente con noi?")

dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("Che ne dici di prenderci una parte del tesoro?")

dialogId("tru-m-vzit2", "font_small", "Aren`t you sorry to leave all this treasure behind?")
dialogStr("Non ti dispiace lasciare indietro tutto questo tesoro?")

dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("È già tanto se riusciremo a uscire noi due.")

dialogId("tru-v-vzit1", "font_big", "Don`t forget our mission.")
dialogStr("Non dimenticare la nostra missione.")

dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("Il tesoro ci sarebbe soltanto d'intralcio.")

dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("Tutto questo sbrilluccicare è un piacere per gli occhi.")

dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Brilla incredibilmente tutto. Tanto da farmi venire le vertigini.")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/chest/dialogs_it.lua <==

dialogId("tru-v-nasly", "font_big", "So we have finally found it.")
dialogStr("E così l'abbiamo finalmente trovato.")

dialogId("tru-m-co", "font_small", "What?")
dialogStr("Cosa?")

dialogId("tru-v-poklad", "font_big", "Captain Silver’s treasure, of course.")
dialogStr("Il tesoro di Capitan Silver, logico.")

dialogId("tru-v-gral", "font_big", "The Holy Grail, of course.")
dialogStr("Il Sacro Graal, ovvio.")

dialogId("tru-v-vkupe", "font_big", "It’s neatly in one place: the treasure and the Grail.")
dialogStr("Semplicemente in un unico posto: il tesoro e il Graal.")

dialogId("tru-m-zrada", "font_small", "I think it’s much too easy to be true.")
dialogStr("Mi sembra troppo facile per essere vero.")

dialogId("tru-m-oznamit", "font_small", "I think that if it really was our goal, the game would let the player know.")
dialogStr("Penso che se questo fosse stato veramente il nostro obiettivo, il giocatore sarebbe stato avvertito.")

dialogId("tru-v-stacit", "font_big", "But I have let them know. That could be enough.")
dialogStr("Ma ora gliel'ho detto io. Dovrebbe bastare.")

dialogId("tru-m-zpochybnit", "font_small", "But I have casted doubts on it. This could confuse them.")
dialogStr("Ma io ho messo in dubbio la cosa. Ciò potrebbe confonderlo.")

dialogId("tru-v-nejspis", "font_big", "Well, all right. PROBABLY this is not what we are looking for.")
dialogStr("E va bene. FORSE questo non è quello che cercavamo.")

dialogId("tru-m-nejistota", "font_small", "That's better. There remains a bit of uncertainty.")
dialogStr("Così è meglio. Ci rimane un po' di incertezza.")

dialogId("tru-m-truhla0", "font_small", "Couldn’t we close that chest?")
dialogStr("Non potremmo chiudere quello scrigno?")

dialogId("tru-m-truhla1", "font_small", "What if we try to close that chest?")
dialogStr("E se chiudesismo lo scrigno?")

dialogId("tru-v-truhla0", "font_big", "It would be much easier with the chest closed.")
dialogStr("Sarebbe molto più facile con lo scrigno chiuso.")

dialogId("tru-v-truhla1", "font_big", "Try to push its lid.")
dialogStr("Prova a spingere il coperchio.")

dialogId("tru-m-vzit0", "font_small", "Won’t we take something with us?")
dialogStr("Non prendiamo niente con noi?")

dialogId("tru-m-vzit1", "font_small", "What about taking some treasure with us?")
dialogStr("Che ne dici di prenderci una parte del tesoro?")

dialogId("tru-m-vzit2", "font_small", "Aren’t you sorry to leave all this treasure behind?")
dialogStr("Non ti dispiace lasciare indietro tutto questo tesoro?")

dialogId("tru-v-vzit0", "font_big", "We will be glad if we manage to get out ourselves.")
dialogStr("È già tanto se riusciremo a uscire noi due.")

dialogId("tru-v-vzit1", "font_big", "Don’t forget our mission.")
dialogStr("Non dimenticare la nostra missione.")

dialogId("tru-v-vzit2", "font_big", "The treasure would only hinder us.")
dialogStr("Il tesoro ci sarebbe soltanto d'intralcio.")

dialogId("tru-v-zrak", "font_big", "All this glinting is a sight for the eyes.")
dialogStr("Tutto questo sbrilluccicare è un piacere per gli occhi.")

dialogId("tru-m-trpyt", "font_small", "Everything here gleams so. It makes me dizzy.")
dialogStr("Brilla incredibilmente tutto. Tanto da farmi venire le vertigini.")
